@@ -26,9 +26,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare '
-           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-           '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-           '-fexceptions',
+           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+           '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+           '-fcf-protection',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h '
@@ -36,7 +36,7 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-fcf-protection -fexceptions',
+ 'CONFIGURE_CFLAGS': '-fexceptions -fcf-protection',
  'CONFIGURE_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
                             '-Werror=format-security '
@@ -47,8 +47,8 @@ build_time_vars = {'ABIFLAGS': '',
                             '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                             '-m64 -march=x86-64-v3 -mtune=generic '
                             '-fasynchronous-unwind-tables '
-                            '-fstack-clash-protection -fcf-protection    '
-                            '-D_GNU_SOURCE -fPIC -fwrapv '
+                            '-fstack-clash-protection -fcf-protection '
+                            '-mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC -fwrapv '
                             '-fno-semantic-interposition -flto '
                             '-fuse-linker-plugin -ffat-lto-objects '
                             '-flto-partition=none -g -std=c11 -Wextra '
@@ -85,6 +85,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--with-dtrace' "
                 "'--with-lto' '--with-ssl-default-suites=openssl' "
+                "'--with-builtin-hashlib-hashes=blake2' "
                 "'--without-static-libpython' "
                 "'--with-wheel-pkg-dir=/usr/share/python3-wheels' "
                 "'--with-valgrind' '--without-ensurepip' "
@@ -92,7 +93,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'build_alias=x86_64-redhat-linux-gnu' "
                 "'host_alias=x86_64-redhat-linux-gnu' "
                 "'PKG_CONFIG_PATH=:/usr/lib64/pkgconfig:/usr/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-fcf-protection -fexceptions  ' 'LDFLAGS= ' "
+                "'CC=gcc' 'CFLAGS=-fexceptions -fcf-protection  ' 'LDFLAGS= ' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
@@ -673,9 +674,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-                    '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-                    '-fexceptions -O2 -flto=auto -ffat-lto-objects '
+                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+                    '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+                    '-fcf-protection -O2 -flto=auto -ffat-lto-objects '
                     '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                     '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -685,14 +686,15 @@ build_time_vars = {'ABIFLAGS': '',
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                     '-march=x86-64-v3 -mtune=generic '
                     '-fasynchronous-unwind-tables -fstack-clash-protection '
-                    '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv '
-                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -flto-partition=none -g -std=c11 '
-                    '-Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                    '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
-                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+                    '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
+                    '-fwrapv -fno-semantic-interposition -flto '
+                    '-fuse-linker-plugin -ffat-lto-objects '
+                    '-flto-partition=none -g -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                    '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                    '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -700,8 +702,8 @@ build_time_vars = {'ABIFLAGS': '',
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                     '-march=x86-64-v3 -mtune=generic '
                     '-fasynchronous-unwind-tables -fstack-clash-protection '
-                    '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv  '
-                    '-fprofile-use -fprofile-correction '
+                    '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
+                    '-fwrapv  -fprofile-use -fprofile-correction '
                     '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
                     '-I/builddir/build/BUILD/Python-3.12.2/Include -fPIC -fPIC',
@@ -710,8 +712,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/include '
                    '-D_BSD_SOURCE -D_DEFAULT_SOURCE -fno-strict-overflow '
                    '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                   '-fcf-protection -fexceptions -fcf-protection -fexceptions '
-                   '-fcf-protection -fexceptions -O2 -flto=auto '
+                   '-fexceptions -fcf-protection -fexceptions -fcf-protection '
+                   '-fexceptions -fcf-protection -O2 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                    '-pipe -Wall -Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -721,14 +723,14 @@ build_time_vars = {'ABIFLAGS': '',
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                    '-march=x86-64-v3 -mtune=generic '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv '
-                   '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                   '-ffat-lto-objects -flto-partition=none -g -std=c11 -Wextra '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
-                   '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                   '-Werror=format-security '
+                   '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
+                   '-fwrapv -fno-semantic-interposition -flto '
+                   '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
+                   '-g -std=c11 -Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden '
+                   '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+                   '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -736,8 +738,8 @@ build_time_vars = {'ABIFLAGS': '',
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                    '-march=x86-64-v3 -mtune=generic '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv  '
-                   '-fprofile-use -fprofile-correction '
+                   '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
+                   '-fwrapv  -fprofile-use -fprofile-correction '
                    '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
                    '-I/builddir/build/BUILD/Python-3.12.2/Include -fPIC -fPIC',
@@ -749,9 +751,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
                     '-fno-strict-overflow -Wsign-compare '
-                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-                    '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-                    '-fexceptions -O2 -flto=auto -ffat-lto-objects '
+                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+                    '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+                    '-fcf-protection -O2 -flto=auto -ffat-lto-objects '
                     '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                     '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -761,14 +763,15 @@ build_time_vars = {'ABIFLAGS': '',
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                     '-march=x86-64-v3 -mtune=generic '
                     '-fasynchronous-unwind-tables -fstack-clash-protection '
-                    '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv '
-                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -flto-partition=none -g -std=c11 '
-                    '-Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                    '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
-                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+                    '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
+                    '-fwrapv -fno-semantic-interposition -flto '
+                    '-fuse-linker-plugin -ffat-lto-objects '
+                    '-flto-partition=none -g -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                    '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                    '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -776,8 +779,8 @@ build_time_vars = {'ABIFLAGS': '',
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                     '-march=x86-64-v3 -mtune=generic '
                     '-fasynchronous-unwind-tables -fstack-clash-protection '
-                    '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv  '
-                    '-fprofile-use -fprofile-correction '
+                    '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
+                    '-fwrapv  -fprofile-use -fprofile-correction '
                     '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
                     '-I/builddir/build/BUILD/Python-3.12.2/Include -fPIC -fPIC',
@@ -818,21 +821,21 @@ build_time_vars = {'ABIFLAGS': '',
                    '_json  _lsprof  _opcode  _pickle  _queue  _random  '
                    '_struct  _xxsubinterpreters  _xxinterpchannels  _zoneinfo  '
                    'audioop  math  cmath  _statistics  _datetime  _decimal  '
-                   'binascii  _bz2  _lzma  zlib  _dbm  _gdbm  readline  _md5  '
-                   '_sha1  _sha2  _sha3  _blake2  pyexpat  _elementtree  '
-                   '_codecs_cn  _codecs_hk  _codecs_iso2022  _codecs_jp  '
-                   '_codecs_kr  _codecs_tw  _multibytecodec  unicodedata  '
-                   '_crypt  fcntl  grp  mmap  ossaudiodev  _posixsubprocess  '
-                   'resource  select  _socket  spwd  syslog  termios  '
-                   '_posixshmem  _multiprocessing  _ctypes  _curses  '
-                   '_curses_panel  _sqlite3  _ssl  _hashlib  _uuid  _tkinter  '
-                   'xxsubtype  _xxtestfuzz  _testbuffer  _testinternalcapi  '
-                   '_testcapi  _testclinic  _testimportmultiple  '
-                   '_testmultiphase  _testsinglephase  _ctypes_test  '
-                   'xxlimited  xxlimited_35  atexit  faulthandler  posix  '
-                   '_signal  _tracemalloc  _codecs  _collections  errno  _io  '
-                   'itertools  _sre  _thread  time  _typing  _weakref  _abc  '
-                   '_functools  _locale  _operator  _stat  _symtable  pwd',
+                   'binascii  _bz2  _lzma  zlib  _dbm  _gdbm  readline  '
+                   '_blake2  pyexpat  _elementtree  _codecs_cn  _codecs_hk  '
+                   '_codecs_iso2022  _codecs_jp  _codecs_kr  _codecs_tw  '
+                   '_multibytecodec  unicodedata  _crypt  fcntl  grp  mmap  '
+                   'ossaudiodev  _posixsubprocess  resource  select  _socket  '
+                   'spwd  syslog  termios  _posixshmem  _multiprocessing  '
+                   '_ctypes  _curses  _curses_panel  _sqlite3  _ssl  _hashlib  '
+                   '_uuid  _tkinter  xxsubtype  _xxtestfuzz  _testbuffer  '
+                   '_testinternalcapi  _testcapi  _testclinic  '
+                   '_testimportmultiple  _testmultiphase  _testsinglephase  '
+                   '_ctypes_test  xxlimited  xxlimited_35  atexit  '
+                   'faulthandler  posix  _signal  _tracemalloc  _codecs  '
+                   '_collections  errno  _io  itertools  _sre  _thread  time  '
+                   '_typing  _weakref  _abc  _functools  _locale  _operator  '
+                   '_stat  _symtable  pwd',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/atexitmodule.o  Modules/faulthandler.o  '
@@ -852,17 +855,16 @@ build_time_vars = {'ABIFLAGS': '',
                     '_lsprof _opcode _pickle _queue _random _struct '
                     '_xxsubinterpreters _xxinterpchannels _zoneinfo audioop '
                     'math cmath _statistics _datetime _decimal binascii _bz2 '
-                    '_lzma zlib _dbm _gdbm readline _md5 _sha1 _sha2 _sha3 '
-                    '_blake2 pyexpat _elementtree _codecs_cn _codecs_hk '
-                    '_codecs_iso2022 _codecs_jp _codecs_kr _codecs_tw '
-                    '_multibytecodec unicodedata _crypt fcntl grp mmap '
-                    'ossaudiodev _posixsubprocess resource select _socket spwd '
-                    'syslog termios _posixshmem _multiprocessing _ctypes '
-                    '_curses _curses_panel _sqlite3 _ssl _hashlib _uuid '
-                    '_tkinter xxsubtype _xxtestfuzz _testbuffer '
-                    '_testinternalcapi _testcapi _testclinic '
-                    '_testimportmultiple _testmultiphase _testsinglephase '
-                    '_ctypes_test xxlimited xxlimited_35',
+                    '_lzma zlib _dbm _gdbm readline _blake2 pyexpat '
+                    '_elementtree _codecs_cn _codecs_hk _codecs_iso2022 '
+                    '_codecs_jp _codecs_kr _codecs_tw _multibytecodec '
+                    'unicodedata _crypt fcntl grp mmap ossaudiodev '
+                    '_posixsubprocess resource select _socket spwd syslog '
+                    'termios _posixshmem _multiprocessing _ctypes _curses '
+                    '_curses_panel _sqlite3 _ssl _hashlib _uuid _tkinter '
+                    'xxsubtype _xxtestfuzz _testbuffer _testinternalcapi '
+                    '_testcapi _testclinic _testimportmultiple _testmultiphase '
+                    '_testsinglephase _ctypes_test xxlimited xxlimited_35',
  'MODULE_ARRAY_STATE': 'yes',
  'MODULE_ATEXIT_LDFLAGS': '',
  'MODULE_AUDIOOP_LDFLAGS': '-lm',
@@ -935,7 +937,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/impl/blake2s.c '
                         '/builddir/build/BUILD/Python-3.12.2/Modules/_blake2/blake2module.h '
                         '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h',
- 'MODULE__BLAKE2_LDFLAGS': '',
+ 'MODULE__BLAKE2_LDFLAGS': '-lssl -lcrypto',
  'MODULE__BLAKE2_STATE': 'yes',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
@@ -1020,13 +1022,10 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__LZMA_CFLAGS': '',
  'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
- 'MODULE__MD5_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/include '
-                       '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/internal '
-                       '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
  'MODULE__MD5_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h \\ '
                      'Modules/_hacl/Hacl_Hash_MD5.h '
                      'Modules/_hacl/Hacl_Hash_MD5.c',
- 'MODULE__MD5_STATE': 'yes',
+ 'MODULE__MD5_STATE': 'disabled',
  'MODULE__MULTIBYTECODEC_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h',
  'MODULE__MULTIBYTECODEC_STATE': 'yes',
  'MODULE__MULTIPROCESSING_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_multiprocessing',
@@ -1041,23 +1040,17 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__QUEUE_STATE': 'yes',
  'MODULE__RANDOM_STATE': 'yes',
  'MODULE__SCPROXY_STATE': 'n/a',
- 'MODULE__SHA1_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/include '
-                        '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/internal '
-                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
  'MODULE__SHA1_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h '
                       '\\ Modules/_hacl/Hacl_Hash_SHA1.h '
                       'Modules/_hacl/Hacl_Hash_SHA1.c',
- 'MODULE__SHA1_STATE': 'yes',
- 'MODULE__SHA2_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/include '
-                        '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/internal '
-                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
+ 'MODULE__SHA1_STATE': 'disabled',
  'MODULE__SHA2_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h '
                       '\\ Modules/_hacl/libHacl_Hash_SHA2.a',
- 'MODULE__SHA2_STATE': 'yes',
+ 'MODULE__SHA2_STATE': 'disabled',
  'MODULE__SHA3_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/hashlib.h '
                       '\\ Modules/_hacl/Hacl_Hash_SHA3.h '
                       'Modules/_hacl/Hacl_Hash_SHA3.c',
- 'MODULE__SHA3_STATE': 'yes',
+ 'MODULE__SHA3_STATE': 'disabled',
  'MODULE__SIGNAL_LDFLAGS': '',
  'MODULE__SOCKET_DEPS': '/builddir/build/BUILD/Python-3.12.2/Modules/socketmodule.h '
                         '/builddir/build/BUILD/Python-3.12.2/Modules/addrinfo.h '
@@ -1121,7 +1114,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection -fexceptions',
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions -fcf-protection',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1154,11 +1147,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                             '-fcf-protection -fexceptions -fcf-protection '
-                             '-fexceptions -fcf-protection -fexceptions -O2 '
+                             '-fexceptions -fcf-protection -fexceptions '
+                             '-fcf-protection -fexceptions -fcf-protection -O2 '
                              '-flto=auto -ffat-lto-objects -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
                              '-Werror=format-security '
@@ -1169,9 +1162,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                              '-m64 -march=x86-64-v3 -mtune=generic '
                              '-fasynchronous-unwind-tables '
-                             '-fstack-clash-protection -fcf-protection    '
-                             '-D_GNU_SOURCE -fPIC -fwrapv '
-                             '-fno-semantic-interposition -flto '
+                             '-fstack-clash-protection -fcf-protection '
+                             '-mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
+                             '-fwrapv -fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g -std=c11 -Wextra '
                              '-Wno-unused-parameter '
@@ -1189,17 +1182,17 @@ build_time_vars = {'ABIFLAGS': '',
                              '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                              '-m64 -march=x86-64-v3 -mtune=generic '
                              '-fasynchronous-unwind-tables '
-                             '-fstack-clash-protection -fcf-protection    '
-                             '-D_GNU_SOURCE -fPIC -fwrapv  -fprofile-use '
-                             '-fprofile-correction '
+                             '-fstack-clash-protection -fcf-protection '
+                             '-mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
+                             '-fwrapv  -fprofile-use -fprofile-correction '
                              '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
                              '-I/builddir/build/BUILD/Python-3.12.2/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-              '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-              '-fexceptions',
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+              '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+              '-fcf-protection',
  'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security '
@@ -1210,11 +1203,12 @@ build_time_vars = {'ABIFLAGS': '',
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                      '-march=x86-64-v3 -mtune=generic '
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
-                     '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv '
-                     '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                     '-ffat-lto-objects -flto-partition=none -g -std=c11 '
-                     '-Wextra -Wno-unused-parameter '
-                     '-Wno-missing-field-initializers -Wstrict-prototypes '
+                     '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE '
+                     '-fPIC -fwrapv -fno-semantic-interposition -flto '
+                     '-fuse-linker-plugin -ffat-lto-objects '
+                     '-flto-partition=none -g -std=c11 -Wextra '
+                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
                      '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
@@ -1226,29 +1220,14 @@ build_time_vars = {'ABIFLAGS': '',
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                      '-march=x86-64-v3 -mtune=generic '
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
-                     '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv  '
-                     '-fprofile-use -fprofile-correction '
+                     '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE '
+                     '-fPIC -fwrapv  -fprofile-use -fprofile-correction '
                      '-I/builddir/build/BUILD/Python-3.12.2/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-                   '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-                   '-fexceptions -O2 -flto=auto -ffat-lto-objects -fexceptions '
-                   '-g -grecord-gcc-switches -pipe -Wall '
-                   '-Werror=format-security '
-                   '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
-                   '-Wp,-D_GLIBCXX_ASSERTIONS '
-                   '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                   '-fstack-protector-strong '
-                   '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                   '-march=x86-64-v3 -mtune=generic '
-                   '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv '
-                   '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                   '-ffat-lto-objects -flto-partition=none -g -std=c11 -Wextra '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+                   '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+                   '-fcf-protection -O2 -flto=auto -ffat-lto-objects '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                    '-Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -1258,8 +1237,23 @@ build_time_vars = {'ABIFLAGS': '',
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                    '-march=x86-64-v3 -mtune=generic '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv  '
-                   '-fprofile-use -fprofile-correction '
+                   '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
+                   '-fwrapv -fno-semantic-interposition -flto '
+                   '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none '
+                   '-g -std=c11 -Wextra -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden '
+                   '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+                   '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+                   '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
+                   '-Wp,-D_GLIBCXX_ASSERTIONS '
+                   '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
+                   '-fstack-protector-strong '
+                   '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
+                   '-march=x86-64-v3 -mtune=generic '
+                   '-fasynchronous-unwind-tables -fstack-clash-protection '
+                   '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
+                   '-fwrapv  -fprofile-use -fprofile-correction '
                    '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
                    '-I/builddir/build/BUILD/Python-3.12.2/Include -fPIC '
@@ -1311,10 +1305,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
                         '-fcf-protection -fexceptions -fcf-protection '
-                        '-fexceptions -fcf-protection -fexceptions -O2 '
-                        '-flto=auto -ffat-lto-objects -fexceptions -g '
+                        '-fexceptions -fcf-protection -O2 -flto=auto '
+                        '-ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security '
                         '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -1324,11 +1318,12 @@ build_time_vars = {'ABIFLAGS': '',
                         '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                         '-march=x86-64-v3 -mtune=generic '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv '
-                        '-fno-semantic-interposition -flto -fuse-linker-plugin '
-                        '-ffat-lto-objects -flto-partition=none -g -std=c11 '
-                        '-Wextra -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers -Wstrict-prototypes '
+                        '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE '
+                        '-fPIC -fwrapv -fno-semantic-interposition -flto '
+                        '-fuse-linker-plugin -ffat-lto-objects '
+                        '-flto-partition=none -g -std=c11 -Wextra '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
@@ -1340,8 +1335,8 @@ build_time_vars = {'ABIFLAGS': '',
                         '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                         '-march=x86-64-v3 -mtune=generic '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-fcf-protection    -D_GNU_SOURCE -fPIC -fwrapv  '
-                        '-fprofile-use -fprofile-correction '
+                        '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE '
+                        '-fPIC -fwrapv  -fprofile-use -fprofile-correction '
                         '-I/builddir/build/BUILD/Python-3.12.2/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
                         '-I/builddir/build/BUILD/Python-3.12.2/Include -fPIC',
@@ -1391,10 +1386,6 @@ build_time_vars = {'ABIFLAGS': '',
                'Modules/_dbm.cpython-312-x86_64-linux-gnu.so '
                'Modules/_gdbm.cpython-312-x86_64-linux-gnu.so '
                'Modules/readline.cpython-312-x86_64-linux-gnu.so '
-               'Modules/_md5.cpython-312-x86_64-linux-gnu.so '
-               'Modules/_sha1.cpython-312-x86_64-linux-gnu.so '
-               'Modules/_sha2.cpython-312-x86_64-linux-gnu.so '
-               'Modules/_sha3.cpython-312-x86_64-linux-gnu.so '
                'Modules/_blake2.cpython-312-x86_64-linux-gnu.so '
                'Modules/pyexpat.cpython-312-x86_64-linux-gnu.so '
                'Modules/_elementtree.cpython-312-x86_64-linux-gnu.so '
